==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/es/vc-menu/Menu.d.ts <==
declare var _default: import("vue").DefineComponent<{
    onClick: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    selectable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    focusable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    multiple: import("vue-types").VueTypeValidableDef<boolean>;
    visible: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    activeKey: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    selectedKeys: import("vue-types").VueTypeDef<import("../_util/type").Key[]>;
    defaultSelectedKeys: import("vue-types").VueTypeDef<import("../_util/type").Key[]> & {
        default: () => import("../_util/type").Key[];
    };
    defaultOpenKeys: import("vue-types").VueTypeDef<import("../_util/type").Key[]> & {
        default: () => import("../_util/type").Key[];
    };
    openKeys: import("vue-types").VueTypeDef<import("../_util/type").Key[]>;
    openAnimation: import("vue-types").VueTypeDef<string | {
        [key: string]: any;
    }>;
    mode: import("vue-types").VueTypeDef<string> & {
        default: string;
    };
    triggerSubMenuAction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    subMenuOpenDelay: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    subMenuCloseDelay: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    level: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    inlineIndent: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    theme: import("vue-types").VueTypeDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    openTransitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    forceSubMenuRender: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    isRootMenu: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    builtinPlacements: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    itemIcon: import("vue-types").VueTypeValidableDef<any>;
    expandIcon: import("vue-types").VueTypeValidableDef<any>;
    overflowedIndicator: import("vue-types").VueTypeValidableDef<any>;
    onSelect: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onDeselect: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    store: {
        selectedKeys: any;
        openKeys: any;
        activeKey: {
            '0-menu-': any;
        };
        defaultActiveFirst: {};
        menuChildrenInfo: {};
        selectedParentUniKeys: any[];
        addChildrenInfo: (key: any, info: any) => void;
        removeChildrenInfo: (key: any) => void;
        getActiveKey: (key: any) => any;
    };
}, any, {}, {
    handleSelect(selectInfo: any): void;
    handleClick(e: any): void;
    onKeyDown(e: any, callback: any): void;
    onOpenChange(event: any): void;
    handleDeselect(selectInfo: any): void;
    getOpenTransitionName(): any;
    saveInnerMenu(ref: any): void;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onClick: (...args: any[]) => any;
    onSelect: (...args: any[]) => any;
    prefixCls: string;
    visible: boolean;
    mode: string;
    getPopupContainer: (...args: any[]) => any;
    builtinPlacements: {
        [key: string]: any;
    };
    onDeselect: (...args: any[]) => any;
    selectable: boolean;
    focusable: boolean;
    isRootMenu: boolean;
    triggerSubMenuAction: string;
    forceSubMenuRender: boolean;
    subMenuOpenDelay: number;
    subMenuCloseDelay: number;
    level: number;
    inlineIndent: number;
    openTransitionName: string;
    theme: string;
    defaultSelectedKeys: import("../_util/type").Key[];
    defaultOpenKeys: import("../_util/type").Key[];
} & {
    multiple?: boolean;
    itemIcon?: any;
    expandIcon?: any;
    openKeys?: import("../_util/type").Key[];
    openAnimation?: string | {
        [key: string]: any;
    };
    selectedKeys?: import("../_util/type").Key[];
    activeKey?: import("../_util/type").Key;
    overflowedIndicator?: any;
}>, {
    onClick: (...args: any[]) => any;
    onSelect: (...args: any[]) => any;
    prefixCls: string;
    visible: boolean;
    mode: string;
    getPopupContainer: (...args: any[]) => any;
    builtinPlacements: {
        [key: string]: any;
    };
    onDeselect: (...args: any[]) => any;
    selectable: boolean;
    focusable: boolean;
    isRootMenu: boolean;
    triggerSubMenuAction: string;
    forceSubMenuRender: boolean;
    subMenuOpenDelay: number;
    subMenuCloseDelay: number;
    level: number;
    inlineIndent: number;
    openTransitionName: string;
    theme: string;
    defaultSelectedKeys: import("../_util/type").Key[];
    defaultOpenKeys: import("../_util/type").Key[];
}>;
export default _default;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/es/vc-menu/Menu.d.ts <==
declare var _default: import("vue").DefineComponent<{
    onClick: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    selectable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    focusable: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    multiple: import("vue-types").VueTypeValidableDef<boolean>;
    visible: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    activeKey: import("vue-types").VueTypeDef<string | number>;
    selectedKeys: import("vue-types").VueTypeDef<(string | number)[]>;
    defaultSelectedKeys: import("vue-types").VueTypeDef<(string | number)[]> & {
        default: () => (string | number)[];
    };
    defaultOpenKeys: import("vue-types").VueTypeDef<(string | number)[]> & {
        default: () => (string | number)[];
    };
    openKeys: import("vue-types").VueTypeDef<(string | number)[]>;
    openAnimation: import("vue-types").VueTypeDef<string | {
        [key: string]: any;
    }>;
    mode: import("vue-types").VueTypeDef<string> & {
        default: string;
    };
    triggerSubMenuAction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    subMenuOpenDelay: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    subMenuCloseDelay: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    level: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    inlineIndent: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    theme: import("vue-types").VueTypeDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    openTransitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    forceSubMenuRender: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    isRootMenu: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    builtinPlacements: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    itemIcon: import("vue-types").VueTypeValidableDef<any>;
    expandIcon: import("vue-types").VueTypeValidableDef<any>;
    overflowedIndicator: import("vue-types").VueTypeValidableDef<any>;
    onSelect: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onDeselect: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    store: {
        selectedKeys: any;
        openKeys: any;
        activeKey: {
            '0-menu-': any;
        };
        defaultActiveFirst: {};
        menuChildrenInfo: {};
        selectedParentUniKeys: any[];
        addChildrenInfo: (key: any, info: any) => void;
        removeChildrenInfo: (key: any) => void;
        getActiveKey: (key: any) => any;
    };
}, any, {}, {
    handleSelect(selectInfo: any): void;
    handleClick(e: any): void;
    onKeyDown(e: any, callback: any): void;
    onOpenChange(event: any): void;
    handleDeselect(selectInfo: any): void;
    getOpenTransitionName(): any;
    saveInnerMenu(ref: any): void;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onClick: (...args: any[]) => any;
    onSelect: (...args: any[]) => any;
    prefixCls: string;
    visible: boolean;
    mode: string;
    getPopupContainer: (...args: any[]) => any;
    builtinPlacements: {
        [key: string]: any;
    };
    onDeselect: (...args: any[]) => any;
    selectable: boolean;
    focusable: boolean;
    isRootMenu: boolean;
    triggerSubMenuAction: string;
    forceSubMenuRender: boolean;
    subMenuOpenDelay: number;
    subMenuCloseDelay: number;
    level: number;
    inlineIndent: number;
    openTransitionName: string;
    theme: string;
    defaultSelectedKeys: (string | number)[];
    defaultOpenKeys: (string | number)[];
} & {
    multiple?: boolean;
    itemIcon?: any;
    expandIcon?: any;
    openKeys?: (string | number)[];
    openAnimation?: string | {
        [key: string]: any;
    };
    selectedKeys?: (string | number)[];
    activeKey?: string | number;
    overflowedIndicator?: any;
}>, {
    onClick: (...args: any[]) => any;
    onSelect: (...args: any[]) => any;
    prefixCls: string;
    visible: boolean;
    mode: string;
    getPopupContainer: (...args: any[]) => any;
    builtinPlacements: {
        [key: string]: any;
    };
    onDeselect: (...args: any[]) => any;
    selectable: boolean;
    focusable: boolean;
    isRootMenu: boolean;
    triggerSubMenuAction: string;
    forceSubMenuRender: boolean;
    subMenuOpenDelay: number;
    subMenuCloseDelay: number;
    level: number;
    inlineIndent: number;
    openTransitionName: string;
    theme: string;
    defaultSelectedKeys: (string | number)[];
    defaultOpenKeys: (string | number)[];
}>;
export default _default;
